@@ -33,6 +33,7 @@
 #include "partitioned_rwlock.h"         // Partitioned_rwlock
 
 #include "prealloced_array.h"
+#include "log_event.h"
 
 /* Forward Declarations */
 class String;
@@ -180,7 +181,7 @@ public:
   }
 
 
-  void print_grant(String *str);
+  void print_grant(THD *thd, String *str);
 
   void set_data(ACL_PROXY_USER *grant)
   {
@@ -203,6 +204,12 @@ public:
                                const LEX_CSTRING &proxied_user,
                                bool with_grant,
                                const char *grantor);
+
+  size_t get_user_length() const { return user ? strlen(user) : 0; }
+
+  size_t get_proxied_user_length() const {
+    return proxied_user ? strlen(proxied_user) : 0;
+  }
 };
 
 #ifndef NO_EMBEDDED_ACCESS_CHECKS
