@@ -1,4 +1,4 @@
-/* Copyright (c) 2010, 2019, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2010, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -325,7 +325,7 @@ bool com_binlog_dump(THD *thd, char *packet, size_t packet_length)
   const uchar* packet_position= (uchar *) packet;
   size_t packet_bytes_todo= packet_length;
 
-  DBUG_ASSERT(!thd->status_var_aggregated);
+  assert(!thd->status_var_aggregated);
   thd->status_var.com_other++;
   thd->enable_slow_log= opt_log_slow_admin_statements;
   if (check_global_access(thd, REPL_SLAVE_ACL))
@@ -376,7 +376,7 @@ bool com_binlog_dump_gtid(THD *thd, char *packet, size_t packet_length)
   Sid_map sid_map(NULL/*no sid_lock because this is a completely local object*/);
   Gtid_set slave_gtid_executed(&sid_map);
 
-  DBUG_ASSERT(!thd->status_var_aggregated);
+  assert(!thd->status_var_aggregated);
   thd->status_var.com_other++;
   thd->enable_slow_log= opt_log_slow_admin_statements;
   if (check_global_access(thd, REPL_SLAVE_ACL))
