@@ -502,6 +502,12 @@ protected:
 	doesn't give any clue that it is called at the end of a statement. */
 	int end_stmt();
 
+	/** Can reuse the template. Mainly used for partition.
+	@retval true Can reuse the mysql_template */
+	virtual bool can_reuse_mysql_template() {
+		return(false);
+	}
+
 
 	/** The multi range read session object */
 	DsMrr_impl		m_ds_mrr;
