@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
@@ -484,7 +484,7 @@ THD *PFS_variable_cache<Var_type>::get_THD(THD *unsafe_thd)
 template <class Var_type>
 THD *PFS_variable_cache<Var_type>::get_THD(PFS_thread *pfs_thread)
 {
-  DBUG_ASSERT(pfs_thread != NULL);
+  assert(pfs_thread != NULL);
   return get_THD(pfs_thread->m_thd);
 }
 
